@@ -12,7 +12,7 @@ from . construct import MakeCustomerExtension
 from . construct import MakeCustomerExtensionExtended
 
 from . ducks import OutputRecord
-from . models import Template
+from . models import ValidatedTemplate
 
 from . io import load_excel
 from . io import save_excel
@@ -25,11 +25,11 @@ app = typer.Typer()
 
 @app.command()
 def template(file_path: Path):
-    save_template(Template, file_path) #type: ignore
+    save_template(ValidatedTemplate, file_path) #type: ignore
 
 @app.command()
 def generate(in_file: Path, out_file: Path, seed: Optional[str] = None):
-    records = list(map(lambda x: Template(**x), load_excel(in_file)))
+    records = map(lambda x: ValidatedTemplate.construct(**x), load_excel(in_file))
 
     if seed:
         routegen = generator(seed)
@@ -40,18 +40,11 @@ def generate(in_file: Path, out_file: Path, seed: Optional[str] = None):
     results: List[OutputRecord] = []
     for record in records:
         results.append(record)
-        results.append(MakeRoute(record.copy()))
-        
-        for departure in MakeDeparture(record.copy()):
-            results.append(departure)
-
-        results.append(MakeSelection(record.copy()))
-
-        for cusex in MakeCustomerExtension(record.copy()):
-            results.append(cusex)
-
-        for cusexex in MakeCustomerExtensionExtended(record.copy()):
-            results.append(cusexex)
+        results.extend(MakeRoute(record))
+        results.extend(MakeDeparture(record))
+        results.extend(MakeSelection(record))
+        results.extend(MakeCustomerExtension(record))
+        results.extend(MakeCustomerExtensionExtended(record))
 
     save_excel(results, out_file)
 
