@@ -82,7 +82,7 @@ def MakeSelection(data: ValidatedTemplate) -> Iterator[Selection]:
         ROUT = data.ROUT,
         RODN = data.RODN,
         SEFB = '4',
-        DDOW = '1111100',
+        DDOW = data.DDOW,
         LOLD = data.ARDY\
             if data.ARDX\
             else None
