@@ -18,10 +18,9 @@ def calc_departures(departureDays: str, leadTime: int) -> List[str]:
     if isinstance(departureDays, list):
         departureDays = ''.join([str(n) for n in departureDays])
 
-    elif isinstance(departureDays, str):
+    elif isinstance(departureDays, int):
         departureDays = ''.join([str(n) for n in str(departureDays)])
     
-    departureDays = ''.join([str(n) for n in departureDays])
     leadTime = int(leadTime)
 
     departureArray = [
